==> helix-0.9.7-src.zip: helix-0.9.7/helix-core/src/main/java/org/apache/helix/store/ZNRecordJsonSerializer.java <==
package org.apache.helix.store;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.helix.ZNRecord;
import org.apache.helix.manager.zk.ZNRecordSerializer;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ZNRecordJsonSerializer implements PropertySerializer<ZNRecord> {
  static private Logger LOG = LoggerFactory.getLogger(ZNRecordJsonSerializer.class);
  private final ZNRecordSerializer _serializer = new ZNRecordSerializer();

  @Override
  public byte[] serialize(ZNRecord data) throws PropertyStoreException {
    return _serializer.serialize(data);
  }

  @Override
  public ZNRecord deserialize(byte[] bytes) throws PropertyStoreException {
    return (ZNRecord) _serializer.deserialize(bytes);
  }

}

==> helix-1.0.0-src.zip: helix-1.0.0/helix-core/src/main/java/org/apache/helix/store/ZNRecordJsonSerializer.java <==
package org.apache.helix.store;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.helix.zookeeper.datamodel.ZNRecord;
import org.apache.helix.manager.zk.ZNRecordSerializer;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ZNRecordJsonSerializer implements PropertySerializer<ZNRecord> {
  static private Logger LOG = LoggerFactory.getLogger(ZNRecordJsonSerializer.class);
  private final ZNRecordSerializer _serializer = new ZNRecordSerializer();

  @Override
  public byte[] serialize(ZNRecord data) throws PropertyStoreException {
    return _serializer.serialize(data);
  }

  @Override
  public ZNRecord deserialize(byte[] bytes) throws PropertyStoreException {
    return (ZNRecord) _serializer.deserialize(bytes);
  }

}
